package com.datacloudsec.scan.service.impl;

import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.dao.HostMapper;
import com.datacloudsec.scan.service.IHost;
import com.datacloudsec.scan.tasks.InitSystemTask;
import com.datacloudsec.utils.IPUtil;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.ObjectUtil;
import java.util.List;
import java.util.Map;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/HostService.class */
public class HostService implements IHost {
    private HostMapper hostMapper = (HostMapper) InstanceUtil.newDaoInstance(HostMapper.class);

    public List<Map<String, Object>> search() {
        return this.hostMapper.search((String) null);
    }

    public int update(Integer id, String hostName, String ip, Integer port, Double cpu, Double disk, Double mem, Integer status, String version, String pversion, Integer taskNum, Integer scaningNum) throws Exception {
        return this.hostMapper.update(id, hostName, ip, port, cpu, disk, mem, status, version, pversion, taskNum, scaningNum);
    }

    public int add(Integer type, String ip) throws Exception {
        List<String> ipList = IPUtil.getIpList();
        if (ipList.contains(ip)) {
            throw new UEException("主机【" + ip + "】与【127.0.0.1】冲突！");
        }
        Integer port = (Integer) TYPE_PORT.get(type);
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        int maxNum = 1;
        if (params != null) {
            maxNum = ObjectUtil.getInt(params.get("maxlbs"), 1);
        }
        int num = this.hostMapper.countHost(type);
        if (maxNum <= num) {
            throw new UEException("引擎数已达到授权上限");
        }
        Integer count = this.hostMapper.getHostCountByTypeAndIp(type, ip);
        if (count == null || count.intValue() <= 0) {
            return this.hostMapper.add(type, ip, Integer.valueOf(port == null ? 0 : port.intValue()));
        }
        throw new UEException("主机已存在，不能添加相同IP的主机");
    }

    public int del(Integer id) throws Exception {
        return this.hostMapper.del(id);
    }

    public Map<String, Object> getAddress(Integer type) throws Exception {
        return this.hostMapper.getAddress(type);
    }

    public Map<String, Object> getHostByType(Integer type) throws Exception {
        return this.hostMapper.getHostByType(type);
    }
}
